# Debug build
DEBUG_BUILD ?= y

# Source directory: don't change this unless the source has been moved for some
#                   reason.
SRC_DIR := src

# Build directory: change this if you don't want the source tree littered with
#                  object files.
BUILD_DIR ?= src

# Target: change this if you want to rename the kernel.
TARGET ?= nano-os

# If a current build exists, use its architecture unless already specified
ifeq ($(wildcard $(TARGET)),$(TARGET))
TARGET_ARCH ?= $(shell file $(TARGET) | sed -e s/.*386.*/x86_32/ -e s/.*x86-64.*/x86_64/)
endif

# Default to x86-32 unless otherwise specified.
TARGET_ARCH ?= x86_32

# From minios's arch.mk: sets up arch-specific flags    
ifeq ($(TARGET_ARCH),x86_32)
ARCH_CPPFLAGS := -D__x86_32__ -D__i386__
ARCH_CFLAGS   := -m32 -march=i686
ARCH_ASFLAGS  := -m32
ARCH_LDFLAGS  := --oformat=elf32-i386 -m elf_i386
ARCH_OBJS     := bootstrap.x86_32.o entry.x86_32.o
else
ifeq ($(TARGET_ARCH),x86_64)
ARCH_CPPFLAGS := -D__x86_64__
ARCH_CFLAGS   := -m64 -mno-red-zone -fno-reorder-blocks -fno-asynchronous-unwind-tables
ARCH_ASFLAGS  := -m64
ARCH_LDFLAGS  := --oformat=elf64-x86-64 -m elf_x86_64
ARCH_OBJS     := bootstrap.x86_64.o entry.x86_64.o
endif
endif

# Default flags
DEF_CPPFLAGS := -Iinclude -D__XEN_INTERFACE_VERSION__=0x00030205
DEF_LDFLAGS  := -nostdlib -T kernel.lds -L.
DEF_CFLAGS   := -std=c99 -nostdlib -fno-builtin
DEF_ASFLAGS  := -D__ASSEMBLY__

ifeq ($(DEBUG_BUILD), y)
DEF_CFLAGS += -g
endif

CPPFLAGS += $(DEF_CPPFLAGS) $(ARCH_CPPFLAGS)
LDFLAGS  += $(DEF_LDFLAGS) $(ARCH_LDFLAGS)
CFLAGS   += $(DEF_CFLAGS) $(ARCH_CFLAGS)
ASFLAGS  += $(DEF_ASFLAGS) $(ARCH_ASFLAGS)

# Make sure we're using gcc
CC = gcc
LD = ld
